# Authors

This is the official list of Fetch.ai authors for copyright purposes.

* Ali Hosseini <ali.hosseini@fetch.ai> [5A11](https://github.com/5A11)
* Peter Bukva <peter.bukva@fetch.ai> [pbukva](https://github.com/pbukva) 
* Jiri Vestfal <jiri.vestfal@fetch.ai> [MissingNO57](https://github.com/MissingNO57)
* Ed Fitzgerald <ed.fitzgerald@fetch.ai> [ejfitzgerald](https://github.com/ejfitzgerald)
* Oleg Panasevych <oleg.panasevych@n-cube.co.uk> [Panasevychol](https://github.com/panasevychol)
* Lokman Rahmani <lokman.rahmani@fetch.ai> [lrahmani](https://github.com/lrahmani)

